\version "2.22.0"

\pointAndClickOff

%% Motivated by
%% https://lists.gnu.org/archive/html/lilypond-user/2021-07/msg00238.html ff
%% a *partial* rewrite of persian.ly from above follows, using SMuFL-glyphs.
%% You will need the Bravura-font, downlaodable at:
%% http://www.smufl.org/fonts/
%% Put the font into:
%% lilypond/usr/share/lilypond/current/fonts/otf/

%% smufldata.ily is unchanged taken from
%% https://github.com/openlilylib/snippets/blob/master/custom-music-fonts/smufl/smufldata.ily
\include "smufldata.ily"

#(define smufl-font "Bravura")

%% taken from
%% https://github.com/openlilylib/snippets/blob/master/custom-music-fonts/smufl/definitions.ily
%% slightly modified
#(define-markup-command (smuflglyph layout props glyphname) (string?)
"DOCME"
  (let* ((glyph-number (assoc-get glyphname smufl-map #f)))
    (if glyph-number
        (interpret-markup layout (cons `((font-name . ,smufl-font)) props)
          (make-fontsize-markup 5 (make-char-markup glyph-number)))
        (begin
          (ly:warning "SMuFL glyph `~a' not found" glyphname)
          point-stencil))))

%% taken from
%% https://github.com/openlilylib/snippets/blob/master/custom-music-fonts/smufl/definitions.ily
%% slightly renamed/modified
#(define (persian-smufl-accidental grob)
"DOCME"
  (let* ((alt (ly:grob-property grob 'alteration))
         (glyphname (assoc-get alt persian-smufl-alteration-glyph-name-alist))
         (show
           (if (and (not (string-null? glyphname))
                    (or (ly:grob-property grob 'forced #f)
                        (null? (ly:grob-object grob 'tie))))
               #t
               #f)))
    (if glyphname
        (if show
            (grob-interpret-markup grob (markup #:smuflglyph glyphname))
            point-stencil)
        (ly:accidental-interface::print grob))))

%% taken from
%% https://github.com/openlilylib/snippets/blob/master/custom-music-fonts/smufl/definitions.ily
%% slightly modified
#(define (smufl-key-signature grob)
"DOCME"
  (let* ((altlist (ly:grob-property grob 'alteration-alist))
         (c0pos (ly:grob-property grob 'c0-position))
         (keysig-stencil '()))
    (for-each
      (lambda (alt)
        (let* ((alteration
                 (if (grob::has-interface grob 'key-cancellation-interface)
                     0
                     (cdr alt)))
               (glyphname
                 (assoc-get
                   alteration persian-smufl-alteration-glyph-name-alist ""))
               (padding ;(cond
                        ;  ((< alteration 0) 0.1)
                        ;  ((= alteration 0) 0.3)
                        ;  ((< alteration 1) 0.1)
                        ;  (else -0.4)))
                        0.2)
               (ypos
                 (key-signature-interface::alteration-positions
                   alt c0pos grob))
               (acc-stencil
                 (fold
                   (lambda (y s)
                     (ly:stencil-add
                       (grob-interpret-markup grob
                         (markup #:raise (/ y 2) #:smuflglyph glyphname))
                       s))
                   empty-stencil
                   ypos)))
          (set! keysig-stencil
                (ly:stencil-combine-at-edge
                  acc-stencil X RIGHT keysig-stencil padding))))
      altlist)
    keysig-stencil))

%% taken from the .zip provided at
%% https://lists.gnu.org/archive/html/lilypond-user/2021-07/msg00238.html
#(define-public KORON -3/10)
#(define-public SORI 1/5)
#(define-public VLAT -1/10)
#(define-public FVLAT -3/5)
#(define-public SVLAT 2/5)

%% from same .zip
pitchnamesEnglish = #`(
  (c-flatflat . ,(ly:make-pitch -1 0 DOUBLE-FLAT))
  (c-flat . ,(ly:make-pitch -1 0 FLAT))
  (c . ,(ly:make-pitch -1 0 NATURAL))
  (c-sharp . ,(ly:make-pitch -1 0 SHARP))
  (c-sharpsharp . ,(ly:make-pitch -1 0 DOUBLE-SHARP))
  (d-flatflat . ,(ly:make-pitch -1 1 DOUBLE-FLAT))
  (d-flat . ,(ly:make-pitch -1 1 FLAT))
  (d . ,(ly:make-pitch -1 1 NATURAL))
  (d-sharp . ,(ly:make-pitch -1 1 SHARP))
  (d-sharpsharp . ,(ly:make-pitch -1 1 DOUBLE-SHARP))
  (e-flatflat . ,(ly:make-pitch -1 2 DOUBLE-FLAT))
  (e-flat . ,(ly:make-pitch -1 2 FLAT))
  (e . ,(ly:make-pitch -1 2 NATURAL))
  (e-sharp . ,(ly:make-pitch -1 2 SHARP))
  (e-sharpsharp . ,(ly:make-pitch -1 2 DOUBLE-SHARP))
  (f-flatflat . ,(ly:make-pitch -1 3 DOUBLE-FLAT))
  (f-flat . ,(ly:make-pitch -1 3 FLAT))
  (f . ,(ly:make-pitch -1 3 NATURAL))
  (f-sharp . ,(ly:make-pitch -1 3 SHARP))
  (f-sharpsharp . ,(ly:make-pitch -1 3 DOUBLE-SHARP))
  (g-flatflat . ,(ly:make-pitch -1 4 DOUBLE-FLAT))
  (g-flat . ,(ly:make-pitch -1 4 FLAT))
  (g . ,(ly:make-pitch -1 4 NATURAL))
  (g-sharp . ,(ly:make-pitch -1 4 SHARP))
  (g-sharpsharp . ,(ly:make-pitch -1 4 DOUBLE-SHARP))
  (a-flatflat . ,(ly:make-pitch -1 5 DOUBLE-FLAT))
  (a-flat . ,(ly:make-pitch -1 5 FLAT))
  (a . ,(ly:make-pitch -1 5 NATURAL))
  (a-sharp . ,(ly:make-pitch -1 5 SHARP))
  (a-sharpsharp . ,(ly:make-pitch -1 5 DOUBLE-SHARP))
  (b-flatflat . ,(ly:make-pitch -1 6 DOUBLE-FLAT))
  (b-flat . ,(ly:make-pitch -1 6 FLAT))
  (b . ,(ly:make-pitch -1 6 NATURAL))
  (b-sharp . ,(ly:make-pitch -1 6 SHARP))
  (b-sharpsharp . ,(ly:make-pitch -1 6 DOUBLE-SHARP))

  (cff . ,(ly:make-pitch -1 0 DOUBLE-FLAT))
  (cf . ,(ly:make-pitch -1 0 FLAT))
  (cv . ,(ly:make-pitch -1 0 VLAT))
  (cfv . ,(ly:make-pitch -1 0 FVLAT))
  (ck . ,(ly:make-pitch -1 0 KORON))
  (c . ,(ly:make-pitch -1 0 NATURAL))
  (co . ,(ly:make-pitch -1 0 SORI))
  (cs . ,(ly:make-pitch -1 0 SHARP))
  (csv . ,(ly:make-pitch -1 0 SVLAT))
  (css . ,(ly:make-pitch -1 0 DOUBLE-SHARP))
  (cx . ,(ly:make-pitch -1 0 DOUBLE-SHARP))

  (dff . ,(ly:make-pitch -1 1 DOUBLE-FLAT))
  (df . ,(ly:make-pitch -1 1 FLAT))
  (dv . ,(ly:make-pitch -1 1 VLAT))
  (dfv . ,(ly:make-pitch -1 1 FVLAT))
  (dk . ,(ly:make-pitch -1 1 KORON))
  (d . ,(ly:make-pitch -1 1 NATURAL))
  (do . ,(ly:make-pitch -1 1 SORI))
  (ds . ,(ly:make-pitch -1 1 SHARP))
  (dsv . ,(ly:make-pitch -1 1 SVLAT))
  (dss . ,(ly:make-pitch -1 1 DOUBLE-SHARP))
  (dx . ,(ly:make-pitch -1 1 DOUBLE-SHARP))

  (eff . ,(ly:make-pitch -1 2 DOUBLE-FLAT))
  (ef . ,(ly:make-pitch -1 2 FLAT))
  (ev . ,(ly:make-pitch -1 2 VLAT))
  (efv . ,(ly:make-pitch -1 2 FVLAT))
  (ek . ,(ly:make-pitch -1 2 KORON))
  (e . ,(ly:make-pitch -1 2 NATURAL))
  (eo . ,(ly:make-pitch -1 2 SORI))
  (es . ,(ly:make-pitch -1 2 SHARP))
  (esv . ,(ly:make-pitch -1 2 SVLAT))
  (ess . ,(ly:make-pitch -1 2 DOUBLE-SHARP))
  (ex . ,(ly:make-pitch -1 2 DOUBLE-SHARP))

  (fff . ,(ly:make-pitch -1 3 DOUBLE-FLAT))
  (ff . ,(ly:make-pitch -1 3 FLAT))
  (fv . ,(ly:make-pitch -1 3 VLAT))
  (ffv . ,(ly:make-pitch -1 3 FVLAT))
  (fk . ,(ly:make-pitch -1 3 KORON))
  (f . ,(ly:make-pitch -1 3 NATURAL))
  (fo . ,(ly:make-pitch -1 3 SORI))
  (fs . ,(ly:make-pitch -1 3 SHARP))
  (fsv . ,(ly:make-pitch -1 3 SVLAT))
  (fss . ,(ly:make-pitch -1 3 DOUBLE-SHARP))
  (fx . ,(ly:make-pitch -1 3 DOUBLE-SHARP))

  (gff . ,(ly:make-pitch -1 4 DOUBLE-FLAT))
  (gf . ,(ly:make-pitch -1 4 FLAT))
  (gv . ,(ly:make-pitch -1 4 VLAT))
  (gfv . ,(ly:make-pitch -1 4 FVLAT))
  (gk . ,(ly:make-pitch -1 4 KORON))
  (g . ,(ly:make-pitch -1 4 NATURAL))
  (go . ,(ly:make-pitch -1 4 SORI))
  (gs . ,(ly:make-pitch -1 4 SHARP))
  (gsv . ,(ly:make-pitch -1 4 SVLAT))
  (gss . ,(ly:make-pitch -1 4 DOUBLE-SHARP))
  (gx . ,(ly:make-pitch -1 4 DOUBLE-SHARP))

  (aff . ,(ly:make-pitch -1 5 DOUBLE-FLAT))
  (af . ,(ly:make-pitch -1 5 FLAT))
  (av . ,(ly:make-pitch -1 5 VLAT))
  (afv . ,(ly:make-pitch -1 5 FVLAT))
  (ak . ,(ly:make-pitch -1 5 KORON))
  (a . ,(ly:make-pitch -1 5 NATURAL))
  (ao . ,(ly:make-pitch -1 5 SORI))
  (as . ,(ly:make-pitch -1 5 SHARP))
  (asv . ,(ly:make-pitch -1 5 SVLAT))
  (ass . ,(ly:make-pitch -1 5 DOUBLE-SHARP))
  (ax . ,(ly:make-pitch -1 5 DOUBLE-SHARP))

  (bff . ,(ly:make-pitch -1 6 DOUBLE-FLAT))
  (bf . ,(ly:make-pitch -1 6 FLAT))
  (bv . ,(ly:make-pitch -1 6 VLAT))
  (bfv . ,(ly:make-pitch -1 6 FVLAT))
  (bk . ,(ly:make-pitch -1 6 KORON))
  (b . ,(ly:make-pitch -1 6 NATURAL))
  (bo . ,(ly:make-pitch -1 6 SORI))
  (bs . ,(ly:make-pitch -1 6 SHARP))
  (bsv . ,(ly:make-pitch -1 6 SVLAT))
  (bss . ,(ly:make-pitch -1 6 DOUBLE-SHARP))
  (bx . ,(ly:make-pitch -1 6 DOUBLE-SHARP)))

#(ly:parser-set-note-names pitchnamesEnglish)

%%%%
%% persian alterations
%%%%
%% No clue if the alterations are correct, I don't know persian music at all
#(define persian-smufl-alteration-glyph-name-alist
  '(
    (-1 . "accidentalDoubleFlat") 
    (-3/5 . "accidentalFlat")     
    (-1/2 . "accidentalFlat")     
    (-3/10 . "accidentalKoron")   
    (-1/10 . "")
    (0 . "accidentalNatural")
    (1/5 . "accidentalSori")
    (2/5 . "accidentalSharp")
    (1/2 . "accidentalSharp")
    (1 . "accidentalDoubleSharp")))

%%%%
%% graces
%%%%
%% Mmhh, do Stem.direction here or via add-grace-property or ad hoc??
startGraceMusic = {
  \temporary \override Flag.stroke-style = #"grace"
  \temporary \override Stem.direction = #DOWN
}

stopGraceMusic = {
  \revert Flag.stroke-style
  \revert Stem.direction
}

%%%%
%% key signatures for Persian modes
%%%%

shurC = #`(
    (1 . ,KORON)
    (2 . ,FLAT)
    (5 . ,FLAT)
    (6 . ,FLAT)
  )

shurD = #`(
    (6 . ,FLAT)
    (2 . ,KORON)
  )

shurE = #`(
    (3 . ,SORI)
  )

shurF = #`(
    (1 . ,FLAT)
    (2 . ,FLAT)
    (4 . ,KORON)
    (5 . ,FLAT)
    (6 . ,FLAT)
  )

shurG = #`(
    (2 . ,FLAT)
    (5 . ,KORON)
    (6 . ,FLAT)
  )

%% alternative if you want to us shur on G with Bb vlat (bfv) 
%% instead of normal Bb (bf)
shurGvlat = #`(
    (2 . ,FLAT)
    (5 . ,KORON)
    (6 . ,FVLAT)
  )

shurA = #`(
    (6 . ,KORON)
  )

shurB = #`(
    (0 . ,SORI)
    (3 . ,SHARP)
  )

shurkC = #`(
    (1 . ,KORON)
    (2 . ,FLAT)
    (4 . ,KORON)
    (5 . ,FLAT)
    (6 . ,FLAT)
  )

shurkD = #`(
    (2 . ,KORON)
    (5 . ,KORON)
    (6 . ,FLAT)
  )

shurkE = #`(
    (3 . ,SORI)
    (6 . ,KORON)
  )

shurkF = #`(
    (0 . ,KORON)
    (1 . ,FLAT)
    (2 . ,FLAT)
    (4 . ,KORON)
    (5 . ,FLAT)
    (6 . ,FLAT)
  )

shurkG = #`(
    (1 . ,KORON)
    (2 . ,FLAT)
    (5 . ,KORON)
    (6 . ,FLAT)
  )

shurkA = #`(
    (2 . ,KORON)
    (6 . ,KORON)
  )

shurkB = #`(
    (0 . ,SORI)
    (3 . ,SORI)
  )

esfahanC = #`(
    (2 . ,FLAT)
    (5 . ,KORON)
  )

esfahanD = #`(
    (0 . ,SHARP)
    (6 . ,KORON)
  )

esfahanE = #`(
    (0 . ,SORI)
    (1 . ,SHARP)
    (3 . ,SHARP)
  )

esfahanF = #`(
    (1 . ,KORON)
    (5 . ,FLAT)
    (6 . ,FLAT)
  )

esfahanG = #`(
    (2 . ,KORON)
    (3 . ,SHARP)
    (6 . ,FLAT)
  )

esfahanA = #`(
    (3 . ,SORI)
    (4 . ,SHARP)
  )

esfahanB = #`(
    (0 . ,SHARP)
    (3 . ,SHARP)
    (4 . ,SORI)
    (5 . ,SHARP)
  )

mokhalefsegahC = #`(
    (2 . ,FLAT)
    (5 . ,KORON)
    (6 . ,KORON)
  )

mokhalefsegahD = #`(
    (0 . ,SORI)
    (6 . ,KORON)
  )

mokhalefsegahE = #`(
    (0 . ,SORI)
    (1 . ,SORI)
    (3 . ,SHARP)
  )

mokhalefsegahF = #`(
    (1 . ,KORON)
    (2 . ,KORON)
    (5 . ,FLAT)
    (6 . ,FLAT)
  )

mokhalefsegahG = #`(
    (2 . ,KORON)
    (3 . ,SORI)
    (6 . ,FLAT)
  )

mokhalefsegahA = #`(
    (3 . ,SORI)
    (4 . ,SORI)
  )

mokhalefsegahB = #`(
    (0 . ,SHARP)
    (3 . ,SHARP)
    (4 . ,SORI)
    (5 . ,SORI)
  )

chahargahC = #`(
    (1 . ,KORON)
    (5 . ,KORON)
  )

chahargahD = #`(
    (0 . ,SHARP)
    (2 . ,KORON)
    (3 . ,SHARP)
    (6 . ,KORON)
  )

chahargahE = #`(
    (0 . ,SORI)
    (1 . ,SHARP)
    (3 . ,SORI)
    (4 . ,SHARP)
  )

chahargahF = #`(
    (1 . ,KORON)
    (4 . ,KORON)
    (6 . ,FLAT)
  )

chahargahG = #`(
    (2 . ,KORON)
    (3 . ,SHARP)
    (5 . ,KORON)
  )

chahargahA = #`(
    (0 . ,SHARP)
    (3 . ,SORI)
    (4 . ,SHARP)
    (6 . ,KORON)
  )

chahargahB = #`(
    (0 . ,SORI)
    (1 . ,SHARP)
    (3 . ,SHARP)
    (4 . ,SORI)
    (5 . ,SHARP)
  )

mahurF = #`(
    (6 . ,FLAT)
  )

mahurG = #`(
    (3 . ,SHARP)
  )

delkashMahurF = #`(
    (1 . ,KORON)
    (2 . ,FLAT)
    (6 . ,FLAT)
  )

hicazG = #`(
    (3 . ,SHARP)
    (2 . ,FLAT)
    (6 . ,FLAT)
  )

hicazA = #`(
    (4 . ,SHARP)
  )

esfahanETF = #`(
    (1 . ,FLAT)
    (5 . ,FLAT)
    (6 . ,FLAT)
  )

esfahanETG = #`(
    (2 . ,FLAT)
    (3 . ,SHARP)
    (6 . ,FLAT)
  )

%%%%
%% persian layout 
%%%%
\layout {
  \context {
    \Score
    \override Accidental.stencil = #persian-smufl-accidental
    \override PhrasingSlur.transparent = ##t
  }
  \context {
    \Score
    %\override PaperColumn.keep-inside-line = ##t
    %\override NonMusicalPaperColumn.keep-inside-line = ##t
  }
  \context {
    \Staff
    \override KeySignature.stencil = #smufl-key-signature
    \override KeyCancellation.stencil = #smufl-key-signature
    \omit TimeSignature
    extraNatural = ##f
  }
  \context {
    \Voice
    \omit DynamicText
    \compressEmptyMeasures
  }
}

